"""django-lambda-theme URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/3.0/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.contrib import admin
from django.shortcuts import render
from django.urls import path, include
from django.views.decorators.cache import cache_page

import debug_toolbar


@cache_page(60 * 0.5)  # convert to seconds
def index(request):
    return render(request, 'index.html')


urlpatterns = [
    path('__debug__/', include(debug_toolbar.urls)),
    path('admin/', admin.site.urls),
    path('', index, name='index'),
]



from . import Library
from .components import Slot
from .media import media_tag

"""
Builtin tags 

* Slot: can be used inside any other component, therefore it can be pre-loaded inside django.
* components_css: import css scripts from rendered components 
* components_js: import js scripts from rendered components 
"""
register = Library()

register.tag('slot', Slot)
register.tag("components_css", media_tag("css"))
register.tag("components_js", media_tag("js"))
